import React, {Component} from 'react';
import IngredientsList from './ingredients-list';
import IngredientForm from './ingredient-form';
import InstructionsList from './instructions-list';
import InstructionForm from './instruction-form';
import addRecipeMutation from '../mutations/add-recipe';
import {
  Row, Col,
  Card, CardHeader, CardBody,
  Button, Form, Input
} from 'reactstrap';

class RecipeForm extends Component {
  state = {
    ingredients: [],
    instructions: []
  }

  constructor() {
    super();
    this.submitRecipe = this.submitRecipe.bind(this);
    this.addIngredient = this.addIngredient.bind(this);
    this.clearIngredientList = this.clearIngredientList.bind(this);
    this.addInstruction = this.addInstruction.bind(this);
    this.clearInstructions = this.clearInstructions.bind(this);
  }

  submitRecipe(event) {
    event.preventDefault();
    const {ingredients, instructions} = this.state;

    addRecipeMutation({
      name: this.recipeNameInput.value,
      ingredients,
      instructions,
      rating: 0
    });

    this.clearIngredientList();
    this.clearInstructions();
    this.recipeNameInput.value = '';
    this.recipeNameInput.focus();
  }

  addIngredient(ingredient) {
    const {ingredients} = this.state;
    this.setState({
      ingredients: [
        ...ingredients,
        ingredient
      ]
    });
  }

  clearIngredientList() {
    this.setState({
      ingredients: []
    });
  }

  addInstruction(instruction) {
    const {instructions} = this.state;
    this.setState({
      instructions: [
        ...instructions,
        instruction
      ]
    });
  }

  clearInstructions() {
    this.setState({
      instructions: []
    });
  }

  render() {
    const {ingredients, instructions} = this.state;
    return (
      <Card color="light" className="mt-2">
        <CardHeader><h2>New Recipe</h2></CardHeader>
        <CardBody>
          <Form onSubmit={this.submitRecipe}>
            <Input innerRef={input=>this.recipeNameInput=input} type="text" placeholder="Recipe name" required/>
            <Row>
              <Col md="6" className="mt-2">
                {(ingredients.length !== 0)
                    ? <IngredientsList list={ingredients}/>
                    : <p>No ingredients</p>
                }
                <IngredientForm onNewIngredient={this.addIngredient} onClear={this.clearIngredientList}/>
              </Col>
              <Col md="6" className="mt-2">
                {(instructions.length !== 0)
                    ? <InstructionsList list={instructions}/>
                    : <p>No instructions</p>
                }
                <InstructionForm onNewInstruction={this.addInstruction} onClear={this.clearInstructions}/>
              </Col>
            </Row>
            <Button color="success" size="lg" className="mt-2">Submit recipe</Button>
            <p>&nbsp;</p>
          </Form>
        </CardBody>
      </Card>
    );
  }
}

export default RecipeForm;
