import React from 'react';
import IngredientsList from './ingredients-list';
import InstructionsList from './instructions-list';
import StarRating from './star-rating';
import Summary from './summary';
import {graphql, createFragmentContainer} from 'react-relay';
import changeRecipeRate from '../mutations/change-recipe-rate';
import removeRecipe from '../mutations/remove-recipe';
import {
  Card, CardTitle, CardHeader, CardBody,
  Button
} from 'reactstrap';


const Recipe = ({recipe}) => {
  const {id, name, ingredients, instructions, rating} = recipe;
  const onRate = rating => {
    changeRecipeRate(rating, id);
  }
  const onDelete = () => {
    removeRecipe(id);
  }
  return (
    <Card>
      <CardHeader>
        <h2>{name} <Button color="success" onClick={onDelete}>Delete</Button></h2>
      </CardHeader>
      <CardBody>
        <CardTitle>Ingredients</CardTitle>
        <IngredientsList list={ingredients}/>
        <CardTitle>Cooking Instructions</CardTitle>
        <InstructionsList list={instructions}/>
        <StarRating starsSelected={rating} onRate={onRate}/>
        <Summary ingredientsCount={ingredients.length} instructionsCount={instructions.length}/>
      </CardBody>
    </Card>
  )
}

export default createFragmentContainer(
  Recipe,
  graphql`
    fragment recipe_recipe on Recipe {
      id
      name
      ingredients {
        name
        amount
        measurement
      }
      instructions
      rating
    }
  `
);
